@@ -43,7 +43,7 @@ if(is.character(path) == TRUE & length(path) > 0) {
   }
 } else {
   # if the argument was empty, then relax
-  cat("using current directory...\n")
+  message("using current directory...")
 }
 
 
@@ -73,9 +73,9 @@ if (gui == TRUE) {
             suppressWarnings(tcltk::.TkUp))) {
         variables = gui.classify(...)
       } else {
-        cat("\n")
-        cat("GUI could not be launched -- default settings will be used;\n")
-        cat("otherwise please pass your variables as command-line agruments\n\n")
+        message("")
+        message("GUI could not be launched -- default settings will be used;")
+        message("otherwise please pass your variables as command-line agruments\n")
       }
 }
 
@@ -269,11 +269,10 @@ features.exist = FALSE
         # link this vector into the variable used for calculations
         mfw.list.of.all = features
       } else {
-        cat("\n")
-        cat("You seem to have chosen an existing set of features\n")
-        cat("Unfortunately, something is wrong: check if your variable\n")
-        cat("has a form of vector\n")
-        cat("\n")
+        message("")
+        message("You seem to have chosen an existing set of features")
+        message("Unfortunately, something is wrong: check if your variable")
+        message("has a form of vector\n")
         stop("Wrong format: a vector of features (e.g. words) was expected")
       }
     # selecting the above vector as a valid set of features
@@ -287,16 +286,16 @@ features.exist = FALSE
       # does the file exist? 
       if(file.exists(features) == TRUE) {
         # file with a vector of features will be loaded
-        cat("\n", "reading a custom set of features from a file...", "\n",sep="")
+        message("\n", "reading a custom set of features from a file...")
         # reading a file: newlines are supposed to be delimiters
-        features = scan(features,what="char",sep="\n",encoding=encoding)
+        features = scan(features, what = "char", sep = "\n", encoding = encoding)
         # getting rid of the lines beginning with the "#" char
-        features = c(grep("^[^#]",features,value=TRUE))
+        features = c(grep("^[^#]", features, value = TRUE))
         # link this vector into the variable used for calculations
         mfw.list.of.all = features
       } else {
         # if there's no such a file, then don't try to use it
-        cat("\n", "file \"",features, "\" could not be found\n",sep="")
+        message("\n", "file \"", features, "\" could not be found")
         stop("Wrong file name")
       }
     # selecting the above vector as a valid set of features
@@ -335,20 +334,19 @@ for(iteration in 1:2) {
         # if yes, then convert the above object into a matrix (just in case)
         frequencies = as.matrix(frequencies)
       } else {
-        cat("\n")
-        cat("You seem to have chosen an existing table with frequencies\n")
-        cat("Unfortunately, something is wrong: check if your variable\n")
-        cat("has a form of matrix/data frame\n")
-        cat("\n")
+        message("")
+        message("You seem to have chosen an existing table with frequencies")
+        message("Unfortunately, something is wrong: check if your variable")
+        message("has a form of matrix/data frame\n")
         stop("Wrong format of the table of frequencies")
       }
       # this code makes sure that the table has variables' names
       if(length(colnames(frequencies)) == 0) {
-        colnames(frequencies) = paste("var",1:length(frequencies[1,]),sep="_")
+        colnames(frequencies) = paste("var", 1:length(frequencies[1,]), sep = "_")
       }
       # this code makes sure that the table has samples' names
       if(length(rownames(frequencies)) == 0) {
-        rownames(frequencies) = paste("sample",1:length(frequencies[,1]),sep="_")
+        rownames(frequencies) = paste("sample", 1:length(frequencies[,1]), sep = "_")
       }
     # selecting the above matrix as a valid corpus
     corpus.exists = TRUE
@@ -361,11 +359,11 @@ for(iteration in 1:2) {
       # does the file exist?
       if(file.exists(frequencies) == TRUE) {
         # file with frequencies will be loaded
-        cat("\n", "reading a file containing frequencies...", "\n",sep="")
-        frequencies = t(read.table(frequencies, encoding=encoding))
+        message("\nreading a file containing frequencies...")
+        frequencies = t(read.table(frequencies, encoding = encoding))
       } else {
         # if there's no such a file, then don't try to use it
-        cat("\n", "file \"",frequencies, "\" could not be found\n",sep="")
+        message("\n", "file \"", frequencies, "\" could not be found")
         stop("Wrong file name")
       }
     # selecting the above matrix as a valid corpus
@@ -377,17 +375,17 @@ for(iteration in 1:2) {
   # If a custom set of features was indicated, try to pick the matching variables only
   if(features.exist == TRUE & corpus.exists == TRUE) {
       # checking if the chosen features do match the columns of the table
-      if(length(grep("TRUE",colnames(frequencies) %in% features)) < 2) {
-        cat("The features you want to analyze do not match the variables' names:\n")
-        cat("\n")
-        cat("Available features:",head(colnames(frequencies)), "...\n")
-        cat("Chosen features:", head(features), "...\n")
-        cat("\n")
-        cat("Check the rotation of your table and the names of its rows and columns.\n")
+      if(length(grep("TRUE", colnames(frequencies) %in% features)) < 2) {
+        message("The features you want to analyze do not match the variables' names:")
+        message("")
+        message("Available features: ", head(colnames(frequencies)), "...")
+        message("Chosen features: ", head(features), "...")
+        message("")
+        message("Check the rotation of your table and the names of its rows and columns.")
         stop("Input data mismatch")
       } else {
         # if everything is right, select the subset of columns from the table:
-        frequencies = frequencies[,colnames(frequencies) %in% features]
+        frequencies = frequencies[ , colnames(frequencies) %in% features]
       }
   }
 
@@ -404,10 +402,9 @@ for(iteration in 1:2) {
   # Additionally, check if the table with frequencies is long enough
   if(corpus.exists == TRUE) {
     if(length(frequencies[,1]) < 2 | length(frequencies[1,]) < 2 ) {
-      cat("\n")
-      cat("There is not enough samples and/or features to be analyzed.\n")
-      cat("Try to use tables of at least two rows by two columns.\n")
-      cat("\n")
+      message("")
+      message("There is not enough samples and/or features to be analyzed.")
+      message("Try to use tables of at least two rows by two columns.\n")
       stop("Wrong size of the table of frequencies")
     }
   }
@@ -415,12 +412,12 @@ for(iteration in 1:2) {
   # 1st iteration: setting the matrix containing the training set (if applicable)
   if(corpus.exists == TRUE & iteration == 1) {
     freq.I.set.0.culling = frequencies
-    cat("Training set successfully loaded.\n")
+    message("Training set successfully loaded.")
   }
   # 2nd iteration: setting the matrix containing the test set (if applicable)
   if(corpus.exists == TRUE & iteration == 2) {
     freq.II.set.0.culling = frequencies
-    cat("Test set successfully loaded.\n")
+    message("Test set successfully loaded.")
   }
 
 # attempts at loading the training set and the test set: the loop returns here
@@ -429,14 +426,14 @@ for(iteration in 1:2) {
 # Two iterations completed, another sanity check should be applied
   # First, let's check if the I set was loaded
   if(!exists("freq.I.set.0.culling") & exists("freq.II.set.0.culling")) {
-    cat("Training set is missing, though.\n")  
-    cat("Trying to build both tables from scratch.\n") 
+    message("Training set is missing, though.")  
+    message("Trying to build both tables from scratch.") 
     corpus.exists = FALSE
   }
   # Secondly, let's check the II set
   if(exists("freq.I.set.0.culling") & !exists("freq.II.set.0.culling")) {
-    cat("Test set is missing, though.\n")  
-    cat("Trying to build both tables from scratch.\n") 
+    message("Test set is missing, though.")  
+    message("Trying to build both tables from scratch.") 
     corpus.exists = FALSE
   }
 ###############################################################################
@@ -467,18 +464,17 @@ for(iteration in 1:2) {
       if(is.list(parsed.corpus) == TRUE & length(parsed.corpus) > 1) {
           # checking if the samples have their names; otherwise, assign generic ones:
           if( length(names(parsed.corpus)) != length(parsed.corpus) ) {
-            names(parsed.corpus) = paste("sample",1:length(parsed.corpus),sep="_")
+            names(parsed.corpus) = paste("sample", 1:length(parsed.corpus), sep="_")
           }
         # if everything is fine, use this variable as a valid corpus
 #        loaded.corpus = parsed.corpus
       } else {
-        cat("\n")
-        cat("The object you've specified as your corpus cannot be used.\n")
-        cat("It should be a list containing particular text samples\n")
-        cat("(vectors containing sequencies of words/n-grams or other features).\n")
-        cat("The samples (elements of the list) should have their names.\n")
-        cat("Alternatively, try to build your corpus from text files (default).\n")
-        cat("\n")
+        message("")
+        message("The object you've specified as your corpus cannot be used.")
+        message("It should be a list containing particular text samples")
+        message("(vectors containing sequencies of words/n-grams or other features).")
+        message("The samples (elements of the list) should have their names.")
+        message("Alternatively, try to build your corpus from text files (default).\n")
         stop("Wrong corpus format")
       } 
   }
@@ -497,10 +493,10 @@ for(iteration in 1:2) {
 # Two iterations completed, another sanity check should be applied
 if(corpus.exists == FALSE) {
     if(length(corpus.of.primary.set) >1 & length(corpus.of.secondary.set) >1 ) {
-      cat("Two subcorpora loaded successfully.\n")  
+      message("Two subcorpora loaded successfully.")  
       corpus.exists = TRUE
     } else {
-      cat("The subcorpora will be loaded from text files...\n")
+      message("The subcorpora will be loaded from text files...")
       corpus.exists = FALSE
     }
 }
@@ -525,10 +521,10 @@ if(corpus.exists == FALSE) {
 
   # Checking whether required files and subdirectories exist
   if(file.exists(training.corpus.dir) == FALSE | file.exists(test.corpus.dir) == FALSE) {
-    cat("\n\n!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!\n",
-        "Working directory should contain two subdirectories: 
-        \"",training.corpus.dir,"\" and \"",test.corpus.dir,"\"\n",
-        "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!\n\n",sep="")
+    message("\n\n!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!\n",
+            "Working directory should contain two subdirectories: 
+            \"", training.corpus.dir, "\" and \"", test.corpus.dir, "\"\n",
+            "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!\n")
     # back to the original working directory
     setwd(original.path)
     # error message
@@ -536,10 +532,10 @@ if(corpus.exists == FALSE) {
   }
   # Checking if the subdirectories contain any stuff
   if(length(filenames.primary.set) <2 | length(filenames.secondary.set) <2) {
-    cat("\n\n!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!\n",
-        "Both subdirectories \"",training.corpus.dir,"\" and \"",
-        test.corpus.dir,"\" should contain at least two text samples!\n",
-        "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!\n\n",sep="")
+    message("\n\n!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!\n",
+            "Both subdirectories \"", training.corpus.dir, "\" and \"",
+            test.corpus.dir, "\"\nshould contain at least two text samples!\n",
+            "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!\n")
     # back to the original working directory
     setwd(original.path)
     # error message
@@ -563,7 +559,7 @@ if(corpus.exists == FALSE) {
                          ngram.size = ngram.size)
 
   # loading text files: test set
-  corpus.of.secondary.set = load.corpus.and.parse(files=filenames.secondary.set,
+  corpus.of.secondary.set = load.corpus.and.parse(files = filenames.secondary.set,
                          corpus.dir = test.corpus.dir,
                          encoding = encoding,
                          markup.type = corpus.format,
@@ -592,12 +588,12 @@ if(corpus.exists == FALSE) {
 if(!exists("freq.I.set.0.culling") | !exists("freq.II.set.0.culling")) {
 
   # blank line on the screen
-  cat("\n")
+  message("")
 
   # both corpora (training set and test set) shoud contain some texts;
   # if the number of text samples is lower than 2, the script will stop
   if(length(corpus.of.primary.set) < 2 || length(corpus.of.secondary.set) < 1) {
-    cat("\n\n","either the training set or the test set is empty!", "\n\n")
+    message("\n\n", "either the training set or the test set is empty!", "\n")
     stop("corpus error")
   }
 
@@ -606,14 +602,14 @@ if(!exists("freq.I.set.0.culling") | !exists("freq.II.set.0.culling")) {
   # frequent words (or n-grams, or anything else) used in the current corpus, 
   # in descending order, without frequencies (just a list of words/features). 
   if (features.exist == TRUE) {
-    cat("\n")
-    cat("using an existing wordlist (vector of features)...\n")
+    message("")
+    message("using an existing wordlist (vector of features)...")
     mfw.list.of.all = features
   } else {
     # Extracting all the words (features) used in the texts of primary set 
     # (or both if "Z-scores all" is set to TRUE)
     wordlist.of.primary.set = c()
-    cat("\n")
+    message("")
     # iterating over the samples stored in corpus.of.primary.set
     for (file in 1 : length(corpus.of.primary.set)) {
       # loading the next sample from the list filenames.primary.set,
@@ -621,21 +617,21 @@ if(!exists("freq.I.set.0.culling") | !exists("freq.II.set.0.culling")) {
       # putting the samples together:
       wordlist.of.primary.set = c(wordlist.of.primary.set, current.text)
       # short message on screen
-      cat(".")
-      if(file/25 == floor(file/25)) { cat("\n")} # a newline every 25th sample
+      message(".", appendLF = FALSE)
+      if(file/25 == floor(file/25)) { message("")} # a newline every 25th sample
     }
     # including words of the secondary set in the reference wordlist (if specified)
       if (reference.wordlist.of.all.samples == TRUE) {
         wordlist.of.secondary.set = c()
-        cat("\n")
+        message("")
         for (file in 1 : length(corpus.of.secondary.set)) {
           # loading the next sample from the list filenames.secondary.set,
           current.text = corpus.of.secondary.set[[file]]
           # putting samples together:
           wordlist.of.secondary.set = c(wordlist.of.secondary.set, current.text)
           # short message on screen
-          cat(".")
-          if(file/25 == floor(file/25)) { cat("\n")} # a newline every 25th sample
+          message(".", appendLF = FALSE)
+          if(file/25 == floor(file/25)) { message("")} # a newline every 25th sample
         }
       } else {
         # otherwise, create an empty vector
@@ -644,12 +640,12 @@ if(!exists("freq.I.set.0.culling") | !exists("freq.II.set.0.culling")) {
       
     # Preparing a sorted frequency list of the whole primary set (or both sets).
     # short message
-    cat("\n")
-    cat(length(c(wordlist.of.primary.set,wordlist.of.secondary.set)),"tokens",
-         "will be used to create a list of features\n")
+    message(" ")
+    message(length(c(wordlist.of.primary.set, wordlist.of.secondary.set)), " tokens ",
+         "will be used to create a list of features")
     # the core procedure: frequency list
-    mfw.list.of.all = sort(table(c(wordlist.of.primary.set,wordlist.of.secondary.set)),
-                            decreasing=T)
+    mfw.list.of.all = sort(table(c(wordlist.of.primary.set, wordlist.of.secondary.set)),
+                            decreasing = TRUE)
     # if the whole list is long, then cut off the tail (e.g., > 5000 mfw)
       if (length(mfw.list.of.all) > mfw.list.cutoff) {
         mfw.list.of.all = mfw.list.of.all[1:mfw.list.cutoff]
@@ -664,7 +660,7 @@ if(!exists("freq.I.set.0.culling") | !exists("freq.II.set.0.culling")) {
       "# purpose it can be manually revised, edited, deleted, culled, etc.", 
       "# You can either delete unwanted words, or mark them with \"#\"",
       "# -----------------------------------------------------------------------",
-      "", file="wordlist.txt", sep="\n")
+      "", file = "wordlist.txt", sep = "\n")
     # the current wordlist into a file
       # checking if encoding conversion is needed
       if(encoding == "native.enc") {
@@ -673,9 +669,8 @@ if(!exists("freq.I.set.0.culling") | !exists("freq.II.set.0.culling")) {
         data.to.be.saved = iconv(mfw.list.of.all, to=encoding)
       }
   # writing the stuff
-  cat(data.to.be.saved,file="wordlist.txt", sep="\n",append=T)
-      
-    
+  cat(data.to.be.saved, file = "wordlist.txt", sep = "\n", append = TRUE)
+  
   }   # <----- conditional expr. if(features.exist == TRUE) terminates here
 
 
@@ -696,7 +691,7 @@ if(!exists("freq.I.set.0.culling") | !exists("freq.II.set.0.culling")) {
     # writing the stuff into files
     setwd("sample_dump_primary_set")
       for(i in names(corpus.of.primary.set)) {
-        cat(corpus.of.primary.set[[i]],file=paste(names(corpus.of.primary.set[i]),".txt",sep=""))
+        cat(corpus.of.primary.set[[i]], file = paste(names(corpus.of.primary.set[i]), ".txt", sep = ""))
       }
     setwd("..")
   }
@@ -712,7 +707,7 @@ if(!exists("freq.I.set.0.culling") | !exists("freq.II.set.0.culling")) {
     # writing the stuff into files
     setwd("sample_dump_secondary_set")
       for(i in names(corpus.of.secondary.set)) {
-        cat(corpus.of.secondary.set[[i]],file=paste(names(corpus.of.secondary.set[i]),".txt",sep=""))
+        cat(corpus.of.secondary.set[[i]], file = paste(names(corpus.of.secondary.set[i]), ".txt", sep = ""))
       }
     setwd("..")
   }
@@ -724,7 +719,7 @@ if(!exists("freq.I.set.0.culling") | !exists("freq.II.set.0.culling")) {
 
 
   # blank line on the screen
-  cat("\n")
+  message("")
 
 
   # preparing a huge table of all the frequencies for the training set
@@ -779,12 +774,12 @@ if(!exists("freq.I.set.0.culling") | !exists("freq.II.set.0.culling")) {
 # #################################################
 
 # Finally, we want to save some variable values for later use
-cat("",file="classify_config.txt",append=F)
+cat("", file = "classify_config.txt", append = FALSE)
 var.name <- function(x) { 
-      if(is.character(x)==TRUE) {
-      cat(paste(deparse(substitute(x)),"=\"",x,"\"", sep=""),file="classify_config.txt",sep="\n",append=T)
+      if(is.character(x) == TRUE) {
+      cat(paste(deparse(substitute(x)), " = \"", x, "\"", sep = ""), file = "classify_config.txt", sep = "\n", append = TRUE)
         } else {
-          cat(paste(deparse(substitute(x)),x, sep="="),file="classify_config.txt",sep="\n",append=T) }
+          cat(paste(deparse(substitute(x)), x, sep = " = "), file = "classify_config.txt", sep = "\n", append = TRUE) }
         }
 
  var.name(corpus.format)
@@ -842,7 +837,7 @@ var.name <- function(x) {
 
 
 # cleaning the outputfile
-cat("",file=outputfile,append=F)
+cat("", file = outputfile, append = FALSE)
 
 # saving the original mfw.max value in mfw.max.original
 # this is useful for subtitles of bootstrap graphs
@@ -857,18 +852,12 @@ total.no.of.possible.attrib = c()
 
 # retrieving the total number of texts to be "guessed"
 # (anonymous texts and unique authorial samples will not be counted)
-authors.I.set = c(gsub("_.*","",rownames(freq.I.set.0.culling)))
-authors.II.set = c(gsub("_.*","",rownames(freq.II.set.0.culling)))
+authors.I.set = c(gsub("_.*", "", rownames(freq.I.set.0.culling)))
+authors.II.set = c(gsub("_.*", "", rownames(freq.II.set.0.culling)))
 perfect.guessing = length(authors.II.set[authors.II.set %in% authors.I.set])
 
 
 
-#
-# CLASSES should be assigned differently!!!!!!!
-#
-#
-#
-
 
 
 
@@ -993,9 +982,9 @@ secondary.set = secondary.set[,start.at:length(secondary.set[1,])]
 
 
 
-cat("\n")
-cat("culling @ ", current.culling,"\t","available words ",
-                  length(primary.set[1,]),"\n")
+message("")
+message("culling @ ", current.culling, "\t", "available words ",
+                  length(primary.set[1,]))
 
 
 
@@ -1021,28 +1010,28 @@ freq.table.both.sets = rbind(primary.set, secondary.set)
 if(tolower(classification.method) == "delta") {
         # a short message on the screen:
         if(distance.measure == "delta") {
-                cat("Calculating classic Delta distances... \n")
+                message("Calculating classic Delta distances...")
         }
         if(distance.measure == "argamon") {
-                cat("Calculating Argamon's Delta distances... \n")
+                message("Calculating Argamon's Delta distances...")
         }
         if(distance.measure == "eder") {
-                cat("Calculating Eder's Delta distances... \n")
+                message("Calculating Eder's Delta distances...")
         }
         if(distance.measure == "eder") {
-                cat("Calculating Eder's Simple distances... \n")
+                message("Calculating Eder's Simple distances...")
         }
         if(distance.measure == "manhattan") {
-                cat("Calculating Manhattan distances... \n")
+                message("Calculating Manhattan distances...")
         }
         if(distance.measure == "canberra") {
-                cat("Calculating Canberra distances... \n")
+                message("Calculating Canberra distances...")
         }
         if(distance.measure == "euclidean") {
-                cat("Calculating Euclidean distances... \n")
+                message("Calculating Euclidean distances...")
         }
         if(distance.measure == "cosine") {
-                cat("Calculating Cosine distances... \n")
+                message("Calculating Cosine distances...")
         }
 }
 
@@ -1074,7 +1063,7 @@ if(mfw > length(colnames(freq.table.both.sets)) ) {
 
 
 # the current task (number of MFW currently analyzed) echoed on the screen
-cat(mfw, " ")
+message(mfw, " ", appendLF = FALSE)
 
 
 
@@ -1151,14 +1140,13 @@ classes.test = gsub("_.*","",rownames(secondary.set))
 
 # returns the ranking of the most likely candidates as a list
 if(final.ranking.of.candidates == TRUE) {
-    cat("\n\n\n",file=outputfile,append=T)
+    cat("\n\n\n", file = outputfile, append = TRUE)
       misclassified.samples = 
                    paste(rownames(secondary.set), "\t-->\t",
                    classification.results)[classes.test!=classification.results]
-      cat(misclassified.samples, file=outputfile, append=T, sep="\n") 
+      cat(misclassified.samples, file = outputfile, append = TRUE, sep = "\n") 
       # temporarily (the results should be made available, eventually)
       rm(misclassified.samples)
-#    }
 }
 
 
@@ -1172,11 +1160,11 @@ if(how.many.correct.attributions == TRUE) {
          c(total.no.of.correct.attrib, no.of.correct.attrib)
     total.no.of.possible.attrib = 
          c(total.no.of.possible.attrib, perfect.guessing)
-    cat("\n",file=outputfile,append=T)
-    cat(mfw, " MFW , culled @ ",current.culling,"%,  ",
-         no.of.correct.attrib," of ", perfect.guessing,"\t(",
-         round(no.of.correct.attrib / perfect.guessing * 100, 1),"%)",
-         "\n",file=outputfile,append=T,sep="")
+    cat("\n", file = outputfile, append = TRUE)
+    cat(mfw, " MFW , culled @ ", current.culling, "%,  ",
+         no.of.correct.attrib, " of ", perfect.guessing, "\t(",
+         round(no.of.correct.attrib / perfect.guessing * 100, 1), "%)",
+         "\n", file = outputfile, append = TRUE, sep = "")
 }
 
 
@@ -1191,13 +1179,13 @@ if(how.many.correct.attributions == TRUE) {
 
 if(cv.folds > 0) {
 
-  cat("\n")
-  cat("cross-validation...\n")
+  message("")
+  message("cross-validation...")
  
 
   #bootstrap.output = "bootstrap_output.txt"
-  # cleaning the bootstrapfile
-  #cat("",file=bootstrap.output,append=F)
+  #cleaning the bootstrapfile
+  #cat("", file = bootstrap.output, append = FALSE)
 
   # creating an empty matrix for the final success scores
   cross.validation.results = c()
@@ -1211,7 +1199,7 @@ if(cv.folds > 0) {
 
     # an additional table combined of frequencies of set I and II
     # just for feeding the bootstrap module 
-    freq.table.both.sets.binded = rbind(primary.set[,1:mfw],secondary.set[,1:mfw])
+    freq.table.both.sets.binded = rbind(primary.set[,1:mfw], secondary.set[,1:mfw])
 
 
     names.of.training.set.orig = rownames(primary.set)
@@ -1230,7 +1218,7 @@ if(cv.folds > 0) {
         # count the number of samples of class i included originally in I set
         no.of.training.samples = sum(as.numeric(classes.training.set == i))
         # determine the class' name, surround the name with word boundary char
-        class.name = paste("\\b",i,"\\b",sep="")
+        class.name = paste("\\b", i, "\\b", sep = "")
         # in both sets, identify the positions of current class' samples 
         pinpoint.samples = grep(class.name, classes.both.sets)
         # sanity check, just in case
@@ -1288,10 +1276,10 @@ if(cv.folds > 0) {
   
   
   # retrieving classes of the new training set
-  classes.training = gsub("_.*","",rownames(training.set))
+  classes.training = gsub("_.*", "", rownames(training.set))
   
   # retrieving classes of the new test set
-  classes.test = gsub("_.*","",rownames(test.set))
+  classes.test = gsub("_.*", "", rownames(test.set))
 
 
   
@@ -1301,11 +1289,11 @@ if(cv.folds > 0) {
                                      classification.results))
       # getting the max. number of samples that couold be guessed
       perfect.guessing.cv = sum(as.numeric(classes.test %in% classes.training))
-      cat("\n",file=outputfile,append=T)
-      cat(mfw, " MFW , culled @ ",current.culling,"%,  ",
-               no.of.correct.attrib," of ", perfect.guessing.cv,"\t(",
-               round(no.of.correct.attrib / perfect.guessing.cv * 100, 1),"%)",
-               "\n",file=outputfile,append=T,sep="")
+      cat("\n", file = outputfile, append = TRUE)
+      cat(mfw, " MFW , culled @ ", current.culling, "%,  ",
+               no.of.correct.attrib, " of ", perfect.guessing.cv, "\t(",
+               round(no.of.correct.attrib / perfect.guessing.cv * 100, 1), "%)",
+               "\n", file = outputfile, append = TRUE, sep = "")
       # percentage of correct attributions
       success.rate.cv = no.of.correct.attrib / perfect.guessing.cv * 100
       # combining results for k folds
@@ -1337,17 +1325,17 @@ if(exists("cross.validation.results.all")) {
 
 # writing distance table(s) to a file (if an appropriate option has been chosen)
 if(save.distance.tables == TRUE && exists("distance.table") == TRUE) {
-  distance.table.filename = paste("distance_table_",mfw,"mfw_",current.culling,"c.txt",sep="")
+  distance.table.filename = paste("distance_table_", mfw, "mfw_", current.culling, "c.txt", sep = "")
     # checking if encoding conversion is needed
     if(encoding == "native.enc") {
       data.to.be.saved = distance.table
     } else {
       data.to.be.saved = distance.table
-      rownames(data.to.be.saved) = iconv(rownames(data.to.be.saved), to=encoding)
-      colnames(data.to.be.saved) = iconv(colnames(data.to.be.saved), to=encoding)
+      rownames(data.to.be.saved) = iconv(rownames(data.to.be.saved), to = encoding)
+      colnames(data.to.be.saved) = iconv(colnames(data.to.be.saved), to = encoding)
     }
   # writing the stuff
-  write.table(file=distance.table.filename, data.to.be.saved)
+  write.table(file = distance.table.filename, data.to.be.saved)
 }
 
 # writing the words (or features) actually used in the analysis
@@ -1358,12 +1346,12 @@ if(save.analyzed.features == TRUE) {
     if(encoding == "native.enc") {
       data.to.be.saved = features.actually.used
     } else {
-      data.to.be.saved = iconv(features.actually.used, to=encoding)
+      data.to.be.saved = iconv(features.actually.used, to = encoding)
     }
   # writing the stuff
   cat(data.to.be.saved,
-     file=paste("features_analyzed_",mfw,"mfw_",current.culling,"c.txt",sep=""),
-     sep="\n")
+     file = paste("features_analyzed_", mfw, "mfw_", current.culling, "c.txt", sep = ""),
+     sep = "\n")
 }
 
 # writing the frequency table that was actually used in the analysis
@@ -1373,12 +1361,12 @@ if(save.analyzed.freqs == TRUE) {
       data.to.be.saved = t(freq.table.both.sets[,1:mfw])
     } else {
       data.to.be.saved = t(freq.table.both.sets[,1:mfw])
-      rownames(data.to.be.saved) = iconv(rownames(data.to.be.saved), to=encoding)
-      colnames(data.to.be.saved) = iconv(colnames(data.to.be.saved), to=encoding)
+      rownames(data.to.be.saved) = iconv(rownames(data.to.be.saved), to = encoding)
+      colnames(data.to.be.saved) = iconv(colnames(data.to.be.saved), to = encoding)
     }
   # writting the stuff -- the file name will be changed accordingly
   write.table(data.to.be.saved,
-     file=paste("frequencies_analyzed_",mfw,"mfw_",current.culling,"c.txt",sep=""))
+     file = paste("frequencies_analyzed_", mfw, "mfw_", current.culling, "c.txt", sep = ""))
 }
 
 
@@ -1402,7 +1390,7 @@ if(save.analyzed.freqs == TRUE) {
 # #################################################
 
 # blank line on the screen
-cat("\n")
+message("")
 
 
 }    # <-- the main loop for(j) returns here
@@ -1420,26 +1408,26 @@ total.no.of.possible.attrib = sum(total.no.of.possible.attrib)
 cat("\nGeneral attributive success:  ", total.no.of.correct.attrib, " of ",
            total.no.of.possible.attrib, " (",
            round(total.no.of.correct.attrib/total.no.of.possible.attrib*100, 1), 
-           "%)\n",file=outputfile,append=T,sep="")
-cat("\nMFWs from ",mfw.min," to ",mfw.max.original,
-                  " @ increment ",mfw.incr,"\nCulling from ",culling.min,
-                  " to ",culling.max," @ increment ",culling.incr,
-                  "\nPronouns deleted: ",delete.pronouns,"\n",
-				  file=outputfile,append=T,sep="")
+           "%)\n", file = outputfile, append = TRUE, sep = "")
+cat("\nMFWs from ", mfw.min, " to ", mfw.max.original,
+                  " @ increment ", mfw.incr, "\nCulling from ", culling.min,
+                  " to ", culling.max, " @ increment ", culling.incr,
+                  "\nPronouns deleted: ", delete.pronouns, "\n",
+				  file = outputfile, append = TRUE, sep = "")
 # additional empty line in outputfile (EOF)
-cat("\n",file=outputfile,append=T)
+cat("\n", file = outputfile, append = TRUE)
 
 
 # the same information (about the current task) on screen
-cat("\nGeneral attributive success:  ", total.no.of.correct.attrib, " of ",
+message("\nGeneral attributive success:  ", total.no.of.correct.attrib, " of ",
            total.no.of.possible.attrib, " (",
            round(total.no.of.correct.attrib/total.no.of.possible.attrib*100,1), 
-           "%, sd =", round(sd(all.guesses),1),"%)\n")
-cat("\nMFWs from ",mfw.min," to ",mfw.max.original,
-                  " @ increment ",mfw.incr,"\nCulling from ",culling.min,
-                  " to ",culling.max," @ increment ",culling.incr,
-                  "\nPronouns deleted: ",delete.pronouns,"\n",sep="")
-cat("\n")
+           "%, sd =", round(sd(all.guesses),1),"%)")
+message("\nMFWs from ", mfw.min, " to ", mfw.max.original,
+                  " @ increment ", mfw.incr, "\nCulling from ", culling.min,
+                  " to ", culling.max, " @ increment ", culling.incr,
+                  "\nPronouns deleted: ", delete.pronouns, sep = "")
+message("")
 
 
 ###########################################################
