@@ -12,13 +12,26 @@ perform.nsc = function(training.set,
                        show.features = FALSE,
                        no.of.candidates = 3) {
 
+
+  # first, sanitizing the type of input data
+  if(length(dim(training.set)) != 2) {
+      stop("train set error: a 2-dimensional table (matrix) is required")
+  }
+  # if a vector (rather than a matrix) was used as a test set, a fake row
+  # will be added; actually, this will be a duplicate of the vector
+  if(is.vector(test.set) == TRUE) {
+      test.set = rbind(test.set, test.set)
+      rownames(test.set) = c("unknown", "unknown-copy")
+      # additionally, duplicating ID of the test classes (if specified)
+      if(length(classes.test.set) == 1) {
+      	  classes.test.set = c(classes.test.set, "unknown-copy")
+      }
+  }
+
   
-  # getting the number of features (e.g. MFWs)
-  no.of.cols = length(training.set[1,])
-    
   # checking if the two sets are of the same size
-  if(length(test.set[1,]) != no.of.cols) {
-          stop("training set and test set should the same number of variables!")
+  if(length(test.set[1,]) != length(training.set[1,])) {
+          stop("training set and test set should have the same number of variables!")
   }
   
   # assigning classes, if not specified
@@ -76,6 +89,15 @@ perform.nsc = function(training.set,
           classification.rankings = rbind(classification.rankings, current.ranking)
   }
   
+  
+  # preparing a confusion table
+  predicted_classes = classification.results
+  actual_classes = classes.test.set
+  confusion.matrix = table(predicted_classes, actual_classes)
+  # getting rid of the classes not represented in the training set (e.g. anonymous samples)
+ # confusion.matrix = confusion.matrix[,rownames(confusion.matrix)]
+
+  
   names(classification.results) = rownames(test.set)
   rownames(classification.rankings) = rownames(test.set)
   rownames(classification.scores) = rownames(test.set)
@@ -86,6 +108,7 @@ perform.nsc = function(training.set,
   attr(classification.results, "rankings") = classification.rankings
   attr(classification.results, "scores") = classification.scores
   attr(classification.results, "features") = the.features
+  attr(classification.results, "confusion_matrix") = confusion.matrix
 
 
 return(classification.results)
